pub struct FittedGradientBoostingClassifier<F: Float> { /* private fields */ }Expand description
Fitted gradient boosting classifier.
Implementations
Sourceimpl<F: Float> FittedGradientBoostingClassifier<F>
impl<F: Float> FittedGradientBoostingClassifier<F>
Sourcepub fn n_estimators(&self) -> usize
pub fn n_estimators(&self) -> usize
Number of estimators per class set.
Sourcepub fn predict_proba(&self, x: &Array2<F>) -> Result<Array2<F>>
pub fn predict_proba(&self, x: &Array2<F>) -> Result<Array2<F>>
Predict class probabilities for each sample.
For binary classification, returns shape (n_samples, 2) with columns
[P(class_0), P(class_1)]. For multi-class, returns (n_samples, n_classes)
using softmax over the OVR log-odds.
Sourcepub fn feature_importances(&self) -> Array1<F>
pub fn feature_importances(&self) -> Array1<F>
Feature importances averaged across all tree sets, normalized to sum to 1.
Each tree’s importances are accumulated and weighted by the number of boosting rounds.