pub struct StackingRegressor<F: Float> { /* private fields */ }Expand description
Stacking regressor.
Base estimators produce predictions, which become features for a meta-estimator that learns to combine them. During fitting, base model predictions are generated via cross-validation to avoid overfitting.
Implementations
Sourceimpl<F: Float> StackingRegressor<F>
impl<F: Float> StackingRegressor<F>
Sourcepub fn new<M>(meta_estimator: M) -> Self
pub fn new<M>(meta_estimator: M) -> Self
Create a new StackingRegressor with the given meta-estimator.
Sourcepub fn with_cv_folds(self, cv_folds: usize) -> Self
pub fn with_cv_folds(self, cv_folds: usize) -> Self
Set the number of CV folds for generating meta-features. Default: 5.